@@ -22,12 +22,13 @@ NULL
 #' * Decimal padding.
 #' * Cell padding.
 #' * Table position.
+#' * Caption width.
 #'
 #' Huxtable tries to guess appropriate widths and height for rows and columns; numeric [width()] and
 #' [height()] are treated as scaling factors.
 #'
-#' Contents are only stored as numbers if a whole column is numeric as defined by [is_a_number()];
-#' otherwise they are stored as text.
+#' Contents are only stored as numbers if a whole column is "numeric", i.e. can
+#' be converted by [as.numeric()]). Otherwise, they are stored as text.
 #'
 #' @return An object of class `Workbook`.
 #' @export
@@ -81,7 +82,10 @@ as_Workbook.huxtable <- function (ht,  Workbook = NULL, sheet = "Sheet 1", write
 
   nr <- nrow(contents)
   contents <- as.data.frame(contents, stringsAsFactors = FALSE)
-  is_a_number_mx <- is_a_number(contents)
+  is_a_number_mx <- suppressWarnings(apply(contents, 2, function (col) {
+    ! is.na(as.numeric(col))
+  }))
+  dim(is_a_number_mx) <- dim(contents) # apply might return a vector :-/
   # for each column we go down it. If everything remaining is one type, we insert it. Otherwise
   # we insert the cell.
   for (j in seq_len(ncol(contents))) {
@@ -164,7 +168,7 @@ as_Workbook.huxtable <- function (ht,  Workbook = NULL, sheet = "Sheet 1", write
     width_mult <- if (is.numeric(width(ht))) width(ht) else 0.5
     openxlsx::setColWidths(wb, sheet, cols = seq_len(ncol(ht)), widths = cw * width_mult * basic_width)
   }
-  if (is.numeric(rh <- row_height(ht))) {
+  if (is.numeric(rh <- row_height(ht)) && length(rh) > 0) {
     table_height <- height(ht)
     if (is.na(table_height) || ! is.numeric(table_height)) table_height <- 1
     basic_height <- 30 * nrow(ht)
