@@ -8,32 +8,55 @@ skip_without_pandoc()
 require_temp_artefacts_dir()
 
 
-validate_markdown <- function(md_string, output_format = "html_document") {
-  force(output_format)
+setup({
+  oo <- options("huxtable.autolabel" = FALSE)
+})
+
+
+teardown({
+  options(oo)
+  if (dir.exists("libs")) try(unlink("libs", recursive = TRUE))
+})
+
+
+validate_markdown <- function(md_string) {
   on.exit({
-    if (exists("tf")) try(file.remove(tf), silent = TRUE)
-    if (exists("outfile")) try(file.remove(outfile), silent = TRUE)
+    try(file.remove(tf), silent = TRUE)
+    try(file.remove(outfile), silent = TRUE)
   })
 
-  tf <- tempfile(pattern = "markdown-example", fileext = ".md", tmpdir = "temp-artefacts")
+  tf <- tempfile(
+          pattern = "markdown-example",
+          fileext = ".md",
+          tmpdir = "temp-artefacts"
+        )
   cat(md_string, file = tf)
+
   expect_silent(
-    outfile <- rmarkdown::render(tf,
-            output_format = output_format,
-            output_file = NULL,
-            output_dir = "temp-artefacts",
-            intermediates_dir = "temp-artefacts",
-            clean = TRUE,
-            quiet = TRUE
-          )
-  ) # no error
+    outfile  <- rmarkdown::render(tf,
+                  output_format     = rmarkdown::html_document(
+                                        pandoc_args = c("--metadata",
+                                          "title=\"Avoid warnings\""
+                                        )
+                                      ),
+                  output_file       = NULL,
+                  output_dir        = "temp-artefacts",
+                  intermediates_dir = "temp-artefacts",
+                  clean             = TRUE,
+                  quiet             = TRUE
+                )
+  )
 }
 
 
 test_render <- function(path, format, output_dir = "temp-artefacts") {
   output <- ""
   force(output_dir)
-  on.exit(if (file.exists(output)) try(file.remove(output), silent = TRUE))
+  oo <- options(huxtable.latex_use_fontspec = FALSE)
+  on.exit({
+    options(oo)
+    if (file.exists(output)) try(file.remove(output), silent = TRUE)
+  })
   expect_error(output <- rmarkdown::render(path,
           output_format     = format,
           quiet             = TRUE,
@@ -68,7 +91,8 @@ test_that("Can knit .Rhtml files to HTML", {
   on.exit(try(file.remove(output_files), silent = TRUE))
   for (i in seq_along(in_files)) {
     expect_error(
-      output_files[i] <- knitr::knit(in_files[i], output = output_files[i], quiet = TRUE),
+      output_files[i] <- knitr::knit(in_files[i], output = output_files[i],
+            quiet = TRUE),
       regexp = NA
     )
     expect_true(file.exists(output_files[i]))
@@ -79,9 +103,15 @@ test_that("Can knit .Rhtml files to HTML", {
 test_that("guess_knitr_output_format() gets it right", {
   skip_on_cran()
   out <- character(0)
-  on.exit(sapply(out, function (x) if (file.exists(x)) try(file.remove(x), silent = TRUE)))
-  expect_silent(out[1] <- knitr::knit("guess-output-format-test.Rhtml", quiet = TRUE))
-  expect_silent(out[2] <- knitr::knit("guess-output-format-test.Rnw", quiet = TRUE))
+  on.exit({
+    lapply(out, function (x) {
+      if (file.exists(x)) try(file.remove(x), silent = TRUE)
+    })
+  })
+  expect_silent(out[1] <- knitr::knit("guess-output-format-test.Rhtml",
+        quiet = TRUE))
+  expect_silent(out[2] <- knitr::knit("guess-output-format-test.Rnw",
+        quiet = TRUE))
 
   test_render("guess-output-format-test-Rmd-html.Rmd", "html_document")
   test_render("guess-output-format-test-Rmd-pdf.Rmd", "pdf_document")
@@ -90,7 +120,8 @@ test_that("guess_knitr_output_format() gets it right", {
 
 
 test_that("Four spaces does not cause <pre><code> markup", {
-  output <- rmarkdown::render("fourspace-html-test.Rmd", output_dir = "temp-artefacts", quiet = TRUE)
+  output <- rmarkdown::render("fourspace-html-test.Rmd",
+        output_dir = "temp-artefacts", quiet = TRUE)
   on.exit(if (exists("output")) try(file.remove(output), silent = TRUE))
   lines <- readLines(output)
   expect_false(any(grepl("findme&lt;/td&gt;", lines)))
@@ -113,29 +144,16 @@ test_that("echo = TRUE does not cause option clash", {
 
 test_that("Various Rmd files render without errors", {
   skip_on_cran()
-  skip_if_not_installed("flextable") # skips on travis no-suggests where no vignettes
 
   test_render_all <- function (path) {
     test_render(path, "pdf_document")
     test_render(path, "html_document")
   }
+
   rmd_paths <- c("table-tester-2.Rmd")
   for (path in rmd_paths) {
     test_render_all(path)
   }
-
-  # design-principles needs a CSV file, so we skip:
-  rmd_filenames <- c("huxtable.Rmd", "huxreg.Rmd", "themes.Rmd")
-  # this system.file may be devtools' patched version; these file paths are used in devtools::test:
-  rmd_paths <- system.file("vignettes", rmd_filenames, package = "huxtable")
-  if (! utils::file_test("-f", rmd_paths[1])) rmd_paths <-
-         base::system.file("doc", rmd_filenames, package = "huxtable")
-  if (! utils::file_test("-f", rmd_paths[1])) skip("Couldn't find vignettes...")
-  for (path in rmd_paths) {
-    file.copy(path, ".", overwrite = TRUE) # copy here so we can get the placeins-header.tex
-    test_render_all(basename(path))
-    file.remove(basename(path))
-  }
 })
 
 
@@ -144,7 +162,8 @@ test_that("Bookdown files", {
   skip_if_not_installed("dplyr")
   skip_if_not_installed("bookdown")
   test_render("bookdown-test.Rmd", "bookdown::pdf_book")
-  test_render("bookdown-test.Rmd", "bookdown::html_book", output_dir = ".") # workaround a bug
+  # output_dir = "." works around a bug:
+  test_render("bookdown-test.Rmd", "bookdown::html_book", output_dir = ".")
 })
 
 
